package com.zehong.system.service.impl;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TTransactionProjectMapper;
import com.zehong.system.domain.TTransactionProject;
import com.zehong.system.service.ITTransactionProjectService;

/**
 * 交易项目Service业务层处理
 * 
 * @author zehong
 * @date 2023-06-06
 */
@Service
public class TTransactionProjectServiceImpl implements ITTransactionProjectService 
{
    @Autowired
    private TTransactionProjectMapper tTransactionProjectMapper;

    /**
     * 查询交易项目
     * 
     * @param transactionProjectId 交易项目ID
     * @return 交易项目
     */
    @Override
    public TTransactionProject selectTTransactionProjectById(Long transactionProjectId)
    {
        return tTransactionProjectMapper.selectTTransactionProjectById(transactionProjectId);
    }

    /**
     * 查询交易项目列表
     * 
     * @param tTransactionProject 交易项目
     * @return 交易项目
     */
    @Override
    public List<TTransactionProject> selectTTransactionProjectList(TTransactionProject tTransactionProject)
    {
        return tTransactionProjectMapper.selectTTransactionProjectList(tTransactionProject);
    }

    /**
     * 新增交易项目
     * 
     * @param tTransactionProject 交易项目
     * @return 结果
     */
    @Override
    public int insertTTransactionProject(TTransactionProject tTransactionProject)
    {
        tTransactionProject.setCreateTime(DateUtils.getNowDate());
        return tTransactionProjectMapper.insertTTransactionProject(tTransactionProject);
    }

    /**
     * 修改交易项目
     * 
     * @param tTransactionProject 交易项目
     * @return 结果
     */
    @Override
    public int updateTTransactionProject(TTransactionProject tTransactionProject)
    {
        tTransactionProject.setUpdateTime(DateUtils.getNowDate());
        return tTransactionProjectMapper.updateTTransactionProject(tTransactionProject);
    }

    /**
     * 批量删除交易项目
     * 
     * @param transactionProjectIds 需要删除的交易项目ID
     * @return 结果
     */
    @Override
    public int deleteTTransactionProjectByIds(Long[] transactionProjectIds)
    {
        return tTransactionProjectMapper.deleteTTransactionProjectByIds(transactionProjectIds);
    }

    /**
     * 删除交易项目信息
     * 
     * @param transactionProjectId 交易项目ID
     * @return 结果
     */
    @Override
    public int deleteTTransactionProjectById(Long transactionProjectId)
    {
        return tTransactionProjectMapper.deleteTTransactionProjectById(transactionProjectId);
    }
}
